#!/bin/bash

#set -xuve

if [ $# -ne 2 ]; then
	echo "Wrong number of arguments"
	echo "E.g.: $0 <ARCH> <EXPID>"
	exit 1
fi

ARCH=$1
EXPID=$2

case $ARCH in
	mn)
		rsrc=/gpfs/scratch/*/*
		error_file="err"
		out_file="out"
		;;
	ithaca)
		rsrc=/scratch/cfu/*
		error_file="\.e"
		;;
	ecmwf)
		rsrc=c2a:/scratch/ms
		error_file="err"
		;;
	hector)
		rsrc=
		error_file=""
		;;
	lindgren)
		rsrc=/cfs/klemming/scratch/*/*
		;;
	jaguar)
		rsrc=
		error_file=""
		;;
	*)
		echo "!!! $ARCH is not available !!!"
		exit 1
		;;
esac

TYPE="sim"
LOG_PATH="$rsrc/$EXPID/LOG_$EXPID"
sdates=$(ls -1 ${LOG_PATH}/${EXPID}_*_${TYPE}_COMPLETED | cut -d '_' -f 3 | uniq)
echo "Name,Queue,Run,Failed,FailQueue,FailRun"
for s in $sdates; do
	mems_chunks=$(ls -1tr ${LOG_PATH}/${EXPID}_${s}_*_${TYPE}_COMPLETED | cut -d '_' -f 4-5 | uniq)
	for m_c in $mems_chunks; do
		job=${EXPID}_${s}_${m_c}_${TYPE}
		submit_time=$(ls -1tr ${LOG_PATH}/${job}.cmd | xargs stat -c %Y)
		failed_times=$(($(ls -1tr ${LOG_PATH}/${job}*${error_file} | wc -l) -1 ))
		start_time=$(grep "Started" $(ls -1tr ${LOG_PATH}/${job}*${out_file} | tail -n 1) | cut -d" " -f 3-)
		start_time=$(date --date="${start_time}" +%s)
		end_time=$(grep "Results" $(ls -1tr ${LOG_PATH}/${job}*${out_file} | tail -n 1) | cut -d" " -f 4-)
		end_time=$(date --date="${end_time}" +%s)
		#queued_time=$(echo "scale=2; (${start_time}-${submit_time}) / 3600" | bc)
		#run_time=$(echo "scale=2; (${end_time}-${start_time}) / 3600" | bc)
		queued_time=$((${start_time}-${submit_time}))
		run_time=$((${end_time}-${start_time}))
		failed_jobs=0; fail_queued_time=0; fail_run_time=0
		for failed_errfile in $(ls -1 ${LOG_PATH}/${job}* | grep $error_file); do
			# be careful not to pick the last err file which is currently in use which depends on platform ??????
			failed_jobs=$((failed_jobs+1))
			failed_errfile_stamp=$(stat -c %Z $failed_errfile)
			fail_queued_time=$(fail_queued_time + $(grep "job_queue_time=" $failed_errfile | tail -n 1 | cut -d '=' -f 2))
			fail_run_time=$(fail_run_time + $((failed_errfile_stamp - $(grep "job_start_time=" $failed_errfile | tail -n 1 | cut -d '=' -f 2))))
		done
		#echo "$job_queue_time $job_run_time $failed_jobs fail_queued_time fail_run_time" > ${LOG_PATH}/${job}_COMPLETED
		echo "${job},${queued_time},${run_time},${failed_times},${fail_queued_time},${fail_run_time}"
	done
done
